import React, {Component} from "react";
import {Layout, Menu} from 'antd';
import './DefaultLayout.less'
import {
    MenuFoldOutlined,
    MenuUnfoldOutlined,
    UploadOutlined,
    UserOutlined,
    VideoCameraOutlined
} from "@ant-design/icons";
import HeaderMenu from "../../Components/HeaderMenu/HeaderMenu";
import PageRouter from "../../Routes/PageRouter";

const {Header, Sider, Content} = Layout;

class DefaultLayout extends Component {
    state = {
        collapsed: true,
    };

    toggle = () => {
        this.setState({
            collapsed: !this.state.collapsed,
        });
    };

    render() {
        return (
            <Layout style={{height: '100vh'}}>
                <Sider
                    trigger={null}
                    collapsible
                    collapsed={this.state.collapsed}
                    theme={'light'}
                    className={'sider'}
                >
                    <div className="logo"/>
                    <Menu theme="light" mode="inline" defaultSelectedKeys={['1']}>
                        <Menu.Item key="1" icon={<UserOutlined/>}>
                            nav 1
                        </Menu.Item>
                        <Menu.Item key="2" icon={<VideoCameraOutlined/>}>
                            nav 2
                        </Menu.Item>
                        <Menu.Item key="3" icon={<UploadOutlined/>}>
                            nav 3
                        </Menu.Item>
                    </Menu>
                </Sider>
                <Layout className="site-layout">
                    <Header className="site-layout-background" style={{padding: 0}}>
                        <div>
                            {this.state.collapsed ?
                                <MenuUnfoldOutlined
                                    className={'trigger'}
                                    onClick={this.toggle}
                                />
                                :
                                <MenuFoldOutlined
                                    className={'trigger'}
                                    onClick={this.toggle}
                                />
                            }
                            <div className={'header-menu'}>
                                <HeaderMenu/>
                            </div>
                        </div>
                    </Header>
                    <Content
                        className="site-layout-background"
                        style={{
                            margin: '24px 16px',
                            padding: 24,
                            minHeight: 280,
                        }}
                    >
                        <PageRouter/>
                    </Content>
                </Layout>
            </Layout>
        );
    }
}

export default DefaultLayout;