import React, {Component} from "react";
import {Layout, message} from 'antd';
import './PostArticleLayout.less'
import MarkdownEditor from "../../Components/MarkdownEditor/MarkdownEditor";
import PostHeader from "../../Components/PostHeader/PostHeader";
import {apiPostArticle, apiPostGetClasses, apiPostGetTags, apiSaveArticle} from "../../API/API";

const {Header, Content} = Layout;

class PostArticleLayout extends Component {
    state = {
        text: '',
        title: '',
        tags: [],
        stags: [],
        aclass: '',
        classes: null,
        cover: '',
        Interval: null
    }

    componentDidMount() {
        apiPostGetClasses().then(res => {
            if (res.data.code === '402') {
                this.setState({
                    classes: res.data.classes,
                })
            }
        })
        apiPostGetTags().then(res => {
            if (res.data.code === '402') {
                this.setState({
                    tags: res.data.tags,
                })
            }
        })
        this.setState({
            Interval: setInterval(this.handleSave, 60000)
        })
    }

    handleTextChange = text => {
        this.setState({
            text: text
        })
    }

    handleTitleChange = title => {
        this.setState({
            title: title
        })
    }

    handlePost = () => {
        if (this.state.title === '') {
            message.warning('请写标题')
        } else if (this.state.text === '') {
            message.warning('请写内容')
        } else {
            clearInterval(this.state.Interval)
            let params = {
                title: this.state.title,
                content: this.state.text,
                tag: this.state.stags,
                cover: this.state.cover,
                class: this.state.aclass,
            }
            apiPostArticle(params).then(res => {
                if (res.data.code === '402') {
                    message.success('发布成功')
                } else if (res.data.code === '401') {
                    message.error(res.data.message)
                    // window.location.href = ""
                } else if (res.data.code === '403') {
                    message.error(res.data.message)
                    // window.location.href = ""
                } else {
                    message.error('错误')
                    // window.location.href = ""
                }
            })
        }
    }

    handleCoverChange = cover => {
        this.setState({
            cover: cover
        })
    }

    handleSave = () => {
        if (this.state.title !== '' || this.state.text !== '') {
            let params = {
                title: this.state.title,
                content: this.state.text,
            }
            apiSaveArticle(params).then(res => {
                if (res.data.code === '402') {
                    message.success('已保存')
                } else {
                    message.error('保存错误')
                }
            })
        }
    }

    handleTagSet = tags => {
        this.setState({
            stags: tags
        })
    }

    handleClassChange = aclass => {
        this.setState({
            aclass: aclass
        })
    }

    render() {
        return (
            <Layout>
                <Header className={'site-layout-background post-header'}>
                    <PostHeader
                        handleTitleChange={this.handleTitleChange.bind(this)}
                        handlePost={this.handlePost.bind(this)}
                        handleSave={this.handleSave.bind(this)}
                        handleTagSet={this.handleTagSet.bind(this)}
                        tags={this.state.tags}
                        handleClassChange={this.handleClassChange.bind(this)}
                        classes={this.state.classes}
                        handleCoverChange={this.handleCoverChange.bind(this)}
                    />
                </Header>
                <Content>
                    <MarkdownEditor handleTextChange={this.handleTextChange.bind(this)}/>
                </Content>
            </Layout>
        )
    }
}

export default PostArticleLayout;